==> labbench-0.23.tar.gz: labbench-0.23/labbench/value.py <==
# This software was developed by employees of the National Institute of
# Standards and Technology (NIST), an agency of the Federal Government.
# Pursuant to title 17 United States Code Section 105, works of NIST employees
# are not subject to copyright protection in the United States and are
# considered to be in the public domain. Permission to freely use, copy,
# modify, and distribute this software and its documentation without fee is
# hereby granted, provided that this notice and disclaimer of warranty appears
# in all copies.
#
# THE SOFTWARE IS PROVIDED 'AS IS' WITHOUT ANY WARRANTY OF ANY KIND, EITHER
# EXPRESSED, IMPLIED, OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, ANY WARRANTY
# THAT THE SOFTWARE WILL CONFORM TO SPECIFICATIONS, ANY IMPLIED WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND FREEDOM FROM
# INFRINGEMENT, AND ANY WARRANTY THAT THE DOCUMENTATION WILL CONFORM TO THE
# SOFTWARE, OR ANY WARRANTY THAT THE SOFTWARE WILL BE ERROR FREE. IN NO EVENT
# SHALL NIST BE LIABLE FOR ANY DAMAGES, INCLUDING, BUT NOT LIMITED TO, DIRECT,
# INDIRECT, SPECIAL OR CONSEQUENTIAL DAMAGES, ARISING OUT OF, RESULTING FROM,
# OR IN ANY WAY CONNECTED WITH THIS SOFTWARE, WHETHER OR NOT BASED UPON
# WARRANTY, CONTRACT, TORT, OR OTHERWISE, WHETHER OR NOT INJURY WAS SUSTAINED
# BY PERSONS OR PROPERTY OR OTHERWISE, AND WHETHER OR NOT LOSS WAS SUSTAINED
# FROM, OR AROSE OUT OF THE RESULTS OF, OR USE OF, THE SOFTWARE OR SERVICES
# PROVIDED HEREUNDER. Distributions of NIST software should also include
# copyright and licensing statements of any third-party software that are
# legally bundled with the code in compliance with the conditions of those
# licenses.

from . import _traits


class any(_traits.Any):
    pass


class bool(_traits.Bool):
    pass


class float(_traits.Float):
    pass


class int(_traits.Int):
    pass


class complex(_traits.Complex):
    pass


class str(_traits.Unicode):
    pass


class bytes(_traits.Bytes):
    pass


class list(_traits.List):
    pass


class tuple(_traits.Tuple):
    pass


class dict(_traits.Dict):
    pass


class Path(_traits.Path):
    pass


class DataFrame(_traits.PandasDataFrame):
    pass


class Series(_traits.PandasSeries):
    pass


class ndarray(_traits.NumpyArray):
    pass


class NetworkAddress(_traits.NetworkAddress):
    pass


# mutate these traits into the right role
_traits.subclass_namespace_traits(
    locals(), role=_traits.Trait.ROLE_VALUE, omit_trait_attrs=["key", "func"]
)

==> labbench-0.30.3.tar.gz: labbench-0.30.3/labbench/value.py <==
# This software was developed by employees of the National Institute of
# Standards and Technology (NIST), an agency of the Federal Government.
# Pursuant to title 17 United States Code Section 105, works of NIST employees
# are not subject to copyright protection in the United States and are
# considered to be in the public domain. Permission to freely use, copy,
# modify, and distribute this software and its documentation without fee is
# hereby granted, provided that this notice and disclaimer of warranty appears
# in all copies.
#
# THE SOFTWARE IS PROVIDED 'AS IS' WITHOUT ANY WARRANTY OF ANY KIND, EITHER
# EXPRESSED, IMPLIED, OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, ANY WARRANTY
# THAT THE SOFTWARE WILL CONFORM TO SPECIFICATIONS, ANY IMPLIED WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND FREEDOM FROM
# INFRINGEMENT, AND ANY WARRANTY THAT THE DOCUMENTATION WILL CONFORM TO THE
# SOFTWARE, OR ANY WARRANTY THAT THE SOFTWARE WILL BE ERROR FREE. IN NO EVENT
# SHALL NIST BE LIABLE FOR ANY DAMAGES, INCLUDING, BUT NOT LIMITED TO, DIRECT,
# INDIRECT, SPECIAL OR CONSEQUENTIAL DAMAGES, ARISING OUT OF, RESULTING FROM,
# OR IN ANY WAY CONNECTED WITH THIS SOFTWARE, WHETHER OR NOT BASED UPON
# WARRANTY, CONTRACT, TORT, OR OTHERWISE, WHETHER OR NOT INJURY WAS SUSTAINED
# BY PERSONS OR PROPERTY OR OTHERWISE, AND WHETHER OR NOT LOSS WAS SUSTAINED
# FROM, OR AROSE OUT OF THE RESULTS OF, OR USE OF, THE SOFTWARE OR SERVICES
# PROVIDED HEREUNDER. Distributions of NIST software should also include
# copyright and licensing statements of any third-party software that are
# legally bundled with the code in compliance with the conditions of those
# licenses.

from . import _traits


class any(_traits.Any):
    pass


class bool(_traits.Bool):
    pass


class float(_traits.Float):
    pass


class int(_traits.Int):
    pass


class complex(_traits.Complex):
    pass


class str(_traits.Unicode):
    pass


class bytes(_traits.Bytes):
    pass


class list(_traits.List):
    pass


class tuple(_traits.Tuple):
    pass


class dict(_traits.Dict):
    pass


class Path(_traits.Path):
    pass


# class DataFrame(_traits.PandasDataFrame):
#     pass


# class Series(_traits.PandasSeries):
#     pass


# class ndarray(_traits.NumpyArray):
#     pass


class NetworkAddress(_traits.NetworkAddress):
    pass


# mutate these traits into the right role
_traits.subclass_namespace_traits(
    locals(), role=_traits.Trait.ROLE_VALUE, omit_trait_attrs=["key", "func"]
)
